@@ -194,7 +194,7 @@ __DATA__
     <select name="model" id="model" class="form-select" required>
       <option value="">Model...</option>
 % for my $m (@$models) {
-      <option value="<%= $m %>" <%= $models && $m eq $model ? 'selected' : '' %>><%= ucfirst $m %></option>
+      <option value="<%= $m %>" <%= $models && lc($m) eq lc($model) ? 'selected' : '' %>><%= ucfirst $m %></option>
 % }
     </select>
   </div>
@@ -220,7 +220,7 @@ __DATA__
 <p></p>
 <div class="row">
   <div class="col">
-    <label for="fields" class="form-label">Field:</label>
+    <label for="fields" class="form-label">Search fields:</label>
     <input type="text" name="fields" id="fields" value="<%= $fields %>" class="form-control" placeholder="field1:value1, field2:value2, etc.">
   </div>
 </div>
@@ -257,7 +257,7 @@ __DATA__
 <b>Group</b>: <%= $setting->{group} %> ,
 <b>Param</b>: <%= $setting->{parameter} %> <b>Control</b>: <i><%= $setting->{control} %></i>
 %   if ($setting->{group_to}) {
-<b>To</b>: <%= $setting->{param_to} %> of <%= $setting->{group_to} %>
+<b>To</b>: <%= $setting->{param_to} %> of the <%= $setting->{group_to} %> group
 %   }
 %   if ($setting->{value}) {
 ,
@@ -266,6 +266,7 @@ __DATA__
 <br>
 % }
 
+
 @@ edit.html.ep
 % layout 'default';
 % title 'Synth::Config';
@@ -274,7 +275,7 @@ __DATA__
   <input type="hidden" name="id" value="<%= $id %>">
 <div class="row">
   <div class="col">
-    <input type="text" name="model" id="model" value="<%= $model %>" class="form-control" required>
+    <input type="text" name="model" id="model" value="<%= ucfirst $model %>" class="form-control" required>
   </div>
   <div class="col">
     <input type="text" name="name" id="name" value="<%= $name %>" class="form-control" required>
@@ -347,14 +348,7 @@ $(document).ready(function() {
       dropdown.append($('<option></option>').val(i).text(text));
     });
   }
-  $("select#group").on('change', function() {
-    populate("group", "parameter");
-  });
-  $("select#group_to").on('change', function() {
-    populate("group_to", "param_to");
-  });
-  $("select#control").on('change', function() {
-    const selected = $("select#control").find(":selected").val();
+  function toggle_patch (selected) {
     if (selected === 'patch') {
       $('label[for="group_to"]').show();
       $("#group_to").show();
@@ -401,10 +395,27 @@ $(document).ready(function() {
       $("#unit").show();
       $("#unit_p").show();
     }
+  }
+  $("select#group").on('change', function() {
+    populate("group", "parameter");
   });
+  $("select#group_to").on('change', function() {
+    populate("group_to", "param_to");
+  });
+  $("select#control").on('change', function() {
+    const selected = $("select#control").find(":selected").val();
+    toggle_patch(selected);
+  });
+  if ('<%= $selected->{control} %>' === 'patch') {
+    toggle_patch('patch');
+  }
+  else {
+    toggle_patch('not-patch');
+  }
 });
 </script>
 
+
 @@ layouts/default.html.ep
 <!DOCTYPE html>
 <html lang="en">
